@@ -4,4 +4,4 @@
 """Tools to used by the Pitt-Google Broker software.
 """
 
-from . import consumer_sim, data_utils, gcp_utils, schema_maps
+from . import consumer_sim, data_utils, gcp_utils, math, schema_maps, tests
